@@ -12,11 +12,11 @@ def unicode2utf8(input=None):
         for key in keys:
             value = input[key]
             del(input[key])
-            input[encode2utf8(key)] = encode2utf8(value)
+            input[unicode2utf8(key)] = unicode2utf8(value)
         return input
     elif data_type == type([]):
         for i in range(len(input)):
-            input[i] = encode2utf8(input[i])
+            input[i] = unicode2utf8(input[i])
         return input
     else:
         return input
